@@ -809,7 +809,7 @@ try_create_dir_monitor (GVfsBackend *backend,
     {
       g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR,
 			G_IO_ERROR_NOT_SUPPORTED,
-			_("Not supported"));
+			_("Operation not supported"));
       
       return TRUE;
     }
